/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.imp;

import java.awt.Image;
import java.awt.datatransfer.Transferable;
import java.util.ArrayList;
import java.util.List;
import javax.swing.Action;
import org.netbeans.api.project.Project;
import org.openide.actions.DeleteAction;
import org.openide.actions.RenameAction;
import org.openide.actions.ToolsAction;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.actions.SystemAction;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;

/**
 * <p>Node representing the root folder for imported isobus files</p>
 *
 * @author Gerben Feenstra
 */
@NbBundle.Messages("isobus root folder name=Isobus")
class IsobusRootNode extends FilterNode{             
        
        private static final String ROOTNODE_ICON = "nl/cloudfarming/client/isobus/type/iso.png";
        
        public IsobusRootNode(Project project, Node original) {
            super(original, new TaskfilesNodeChildren(original), new ProxyLookup(Lookups.singleton(project), original.getLookup()));
        }
                
        /**
         * Import isobus action
         *
         * @param context
         * @return
         */
        @Override
        public Action[] getActions(boolean context) {
            return new Action[0];
        }

        @Override
        public Image getIcon(int type) {
            return ImageUtilities.loadImage(ROOTNODE_ICON);
        }

        @Override
        public Image getOpenedIcon(int type) {
            return getIcon(type);
        }

        @Override
        public String getDisplayName() {
            return Bundle.isobus_root_folder_name();
        }

        @Override
        public String getHtmlDisplayName() {
            return getDisplayName();
        }

        // TODO: Fix
        @Override
        public HelpCtx getHelpCtx() {
            return new HelpCtx("nl.cloudfarming.client.isobus.explorer");
        }

        @Override
        public PasteType getDropType(Transferable t, int action, int index) {
            return null;
        }
    
    
    public static class TaskfilesNodeChildren extends FilterNode.Children {

        public TaskfilesNodeChildren(Node node) {
            super(node);
        }

        @Override
        protected Node[] createNodes(Node object) {
            List<Node> result = new ArrayList<>();

            for (Node node : super.createNodes(object)) {
                result.add(new TaskDataFolderNode(node));
            }

            return result.toArray(new Node[0]);
        }
    }
    
    /**
     * Represents the folder where the TASKDATA.XML and optionally GRD00000x.bin and TLG00000x.BIN and TLG00000x.XML are stored    
     * 
     */
    private static class TaskDataFolderNode extends FilterNode {

        private static final String TASKDATA_ICON = "nl/cloudfarming/client/isobus/type/iso.png";
        
        public TaskDataFolderNode(Node original) {
            super(original, new FilterNode.Children(original));
        }

        @Override
        public Action[] getActions(boolean context) {
            return new Action[] {
                SystemAction.get(DeleteAction.class),
                SystemAction.get(RenameAction.class),
                null,
                SystemAction.get(ToolsAction.class)
            };
        }

        @Override
        public PasteType getDropType(Transferable t, int action, int index) {
            return null;
        }
        
        @Override
        public Image getOpenedIcon(int type) {
            return getIcon(type);
        }

        // TODO: Fix
        @Override
        public HelpCtx getHelpCtx() {
            return new HelpCtx("nl.cloudfarming.client.isobus.type.explorer");
        }
        
        @Override
        public Image getIcon(int type) {
            return ImageUtilities.loadImage(TASKDATA_ICON);
        }

        @Override
        public boolean canCopy() {
            return false;
        }

        @Override
        public boolean canCut() {
            return false;
        } 
    }
}
